@@ -17,8 +17,4 @@
 # along with jsonConfig.  If not, see <http://www.gnu.org/licenses/>.
 #===============================================================================
 
-from config import Config
-from editor import ConfigEditor
-from constants import *
-
-__version__ = '0.1.1'
+__version__ = '0.1.2'
